#!/bin/bash

source `which setPortNumbers.sh`

scriptName=`basename $0`
usage () {
    echo "
Usage: ${scriptName} [options]
Options:
  -h, --help: prints this usage message
  --veto-choice <choice>: specifies which parts of the veto system to include
      (\"off\", \"TDC\", \"ADC\", \"Hybrid\", \"TDC+ADC\", or \"TDC+Hybrid\") [default=\"TDC+ADC\"]
  --V1724-enabled <choice>: specifies whether to include the V1724 boards in the system
      (\"yes\", \"no\") [default=\"yes\"]
Examples: ${scriptName} --veto-choice \"TDC\"
" >&2
}

# process command-line arguments
vetoChoice="TDC+ADC"
#vetoChoice="off"
V1724Enabled="yes"
OPTIND=1
while getopts "h-:" opt; do
    if [ "$opt" = "-" ]; then
        opt=$OPTARG
    fi
    case $opt in
        h | help)
            usage
            exit 1
            ;;
        veto-choice)
            vetoChoice=${!OPTIND}
            let OPTIND=$OPTIND+1
            ;;
        V1724-enabled)
            V1724Enabled=${!OPTIND}
            let OPTIND=$OPTIND+1
            ;;
        *)
            usage
            exit 1
            ;;
    esac
done
shift $(($OPTIND - 1))

# create the configuration file for PMT
tempFile="/tmp/pmtConfig.$$"

echo "BoardReaderMain dsfr1 $frPort0" >> $tempFile
echo "BoardReaderMain dsfr1 $frPort1" >> $tempFile
echo "BoardReaderMain dsfr1 $frPort2" >> $tempFile
echo "BoardReaderMain dsfr1 $frPort3" >> $tempFile
echo "BoardReaderMain dsfr2 $frPort0" >> $tempFile
echo "BoardReaderMain dsfr2 $frPort1" >> $tempFile
if [[ "$V1724Enabled" == "yes" ]]; then
    echo "BoardReaderMain dsfr2 $frPort2" >> $tempFile
    echo "BoardReaderMain dsfr2 $frPort3" >> $tempFile
    echo "BoardReaderMain dsfr3 $frPort0" >> $tempFile
    echo "BoardReaderMain dsfr3 $frPort1" >> $tempFile
    echo "BoardReaderMain dsfr3 $frPort2" >> $tempFile
fi
if [[ "$vetoChoice" != "off" ]]; then
    echo "BoardReaderMain dsfr4 $frPort0" >> $tempFile
fi
echo "EventBuilderMain dseb1 $ebPort0" >> $tempFile
echo "EventBuilderMain dseb1 $ebPort1" >> $tempFile
echo "EventBuilderMain dseb1 $ebPort2" >> $tempFile
echo "EventBuilderMain dseb1 $ebPort3" >> $tempFile
echo "EventBuilderMain dseb2 $ebPort0" >> $tempFile
echo "EventBuilderMain dseb2 $ebPort1" >> $tempFile
echo "EventBuilderMain dseb2 $ebPort2" >> $tempFile
echo "EventBuilderMain dseb2 $ebPort3" >> $tempFile
echo "EventBuilderMain dseb3 $ebPort0" >> $tempFile
echo "EventBuilderMain dseb3 $ebPort1" >> $tempFile
echo "EventBuilderMain dseb3 $ebPort2" >> $tempFile
echo "EventBuilderMain dseb3 $ebPort3" >> $tempFile
echo "EventBuilderMain dseb4 $ebPort0" >> $tempFile
echo "EventBuilderMain dseb4 $ebPort1" >> $tempFile
echo "EventBuilderMain dseb4 $ebPort2" >> $tempFile
echo "EventBuilderMain dseb4 $ebPort3" >> $tempFile
echo "AggregatorMain   dsag  $agPort0" >> $tempFile  # remember to change agg node below!
echo "AggregatorMain   dsag  $agPort1" >> $tempFile  # remember to change agg node below!

# clean up any stale shared memory segment on the aggregator machine
let shmKey=1078394880+${pmtPort}
shmKeyString=`printf "0x%x" ${shmKey}`
rsh dsag "ipcs | grep ${shmKeyString} | awk '{print \$2}' | xargs ipcrm -m 2>/dev/null"

# start PMT
pmt.rb -p $pmtPort -d $tempFile --logpath /daqlogs --display :50.0 --preload /home/daq/FSYNC/fake_fsync.so
rm $tempFile
