#ifndef ds50daq_DAQ_V1495Driver_hh
#define ds50daq_DAQ_V1495Driver_hh

#include <memory>
#include "fhiclcpp/fwd.h"
#include "artdaq-core/Data/Fragments.hh"
#include "DS50FragmentGenerator.hh"
#include "darksidecore/Data/V1495Fragment.hh"
#include "artdaq/Application/MPI2/StatisticsHelper.hh"

namespace detail {
  class caen_io;
}

namespace ds50 {
  // V1495Driver reads DS50 events from the board
  class V1495Driver : public DS50FragmentGenerator {
    public:
      static const std::string FRAGMENTS_PROCESSED_STAT_KEY;
      static const std::string READ_TIME_STAT_KEY;
      static const std::string FRAGMENT_CREATE_TIME_STAT_KEY;
      static const std::string REGISTER_RW_TIME_STAT_KEY;
      static const std::string IRQWAIT_TIME_STAT_KEY;

      static const int NO_CHOICE;
      static const int VETO_OFF;
      static const int ADC_SLAVE;
      static const int HYBRID;

      explicit V1495Driver(fhicl::ParameterSet const &);
      virtual ~V1495Driver() noexcept;

    private:
      void start_ () override;
      void stop_ () override;
      void pause_ () override;
      void resume_ () override;
      bool getNext__(artdaq::FragmentPtrs & output) override;

      std::unique_ptr<detail::caen_io> caen_io_;
      bool dont_stop_;
      int irqwait_ms_, irqwait_checks_;
      int irqlost_;
      V1495Fragment::metadata metadata_;
      struct timeval timing_;
      size_t timing_ev_; 

      artdaq::detail::RawFragmentHeader::type_t fr_type_;

      void init_link (fhicl::ParameterSet const &);
      void init_metadata (fhicl::ParameterSet const &);
      void init_trigger (fhicl::ParameterSet const &);
      void init_channels (fhicl::ParameterSet const &);
      void init_veto (fhicl::ParameterSet const &);
      void close_link ();

      // attributes and methods for statistics gathering & reporting
      artdaq::StatisticsHelper statsHelper_;
      std::string buildStatisticsString_();
  };
}
#endif /* ds50daq_DAQ_V1495Driver_hh */
